import os
import cv2

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.animation as animation
from IPython.display import HTML

def get_animation():

    image_folder = "frames"
    image_folder = os.path.abspath(image_folder)

    # Get all image filenames from the folder
    image_files = sorted(
        [f for f in os.listdir(image_folder) if f.endswith(".png") or f.endswith(".jpg")]
    )

    # Get the larges image size
    height = 0
    width = 0
    for image in image_files:
        last_image = cv2.imread(os.path.join(image_folder, image))
        height_, width_, _ = last_image.shape
        height = max(height_, height)
        width = max(width_, width)

    frames = []
    # Loop through all images and copy them to the new image with the same size
    for i, image_file in enumerate(image_files):
        # Open each image
        img = cv2.imread(os.path.join(image_folder, image_file))

        # Crop the image
        nx = 10
        cropped_image = img[:, nx:]
        height_cropped, width_cropped, _ = cropped_image.shape

        # Calculate the position to place the image on the origin
        x_offset = 0
        y_offset = 0  # Placing all images at the top

        # Create a new blank image with the size of the last frame
        frame = 255 * np.ones((height, width, 3), dtype=np.uint8)
        frame[y_offset : y_offset + height_cropped, x_offset : x_offset + width_cropped] = (
            cropped_image
        )

        frames.append(cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))

    ## Create an matplotlib animation

    # Create a figure and axis
    fig, ax = plt.subplots(figsize=(16*0.7, 7*0.7))

    # Display the first image
    img = ax.imshow(frames[0])

    # Hide the axes
    a = ax.axis("off")

    # Function to update the image
    def update(frame):
        img.set_data(frames[frame])

    # Create animation
    ani = animation.FuncAnimation(fig, update, frames=len(frames), interval=1000)
    ani.save(os.path.abspath("images/animation.mp4"), writer="ffmpeg")

    return HTML('<video height="400" controls>\n<source src="images/animation.mp4" type="video/mp4">\nYour browser does not support the video tag.</video>')
